require "spec_helper"

RSpec.describe XpRubyClient::Configurator do
  before(:each) {ENV["XP_RUBY_CLIENT_HOST"] = "http://lvh.me:5000"}

  it "parses a given block with required args and returns correct configutaion" do
    conn = described_class.new do |config|
      config.application = "web"
      config.segments = {}
      config.assigned = []
    end
    expect(conn.base_url).to eq("http://lvh.me:5000/assigner/application/web")
    expect(conn.timeout).to eq(100) # default
  end

  it "raises an error if application is not set" do
    expect {
      described_class.new do |config|
      end
    }.to raise_error(described_class::NotSetError)
  end

  it "raises an error if environment variable XP_RUBY_CLIENT_HOST is not set" do
    ENV["XP_RUBY_CLIENT_HOST"] = nil
    expect {
      described_class.new do |config|
        config.application = "web"
      end.base_url
    }.to raise_error KeyError
  end
end
