require "ostruct"
require "spec_helper"

RSpec.describe XpRubyClient::Requester do
  before(:each) do
    ENV["XP_RUBY_CLIENT_HOST"] = "http://localhost:5000"
    @conn = XpRubyClient::Configurator.new do |config|
      config.application = "web"
      config.timeout = 30
    end
    @empty_resp = OpenStruct.new({body: JSON.dump({"unassign"=>[], "assign"=>[]}), status: 200})
  end

  it "uses default segments and assigned if they are not set" do
    expect_any_instance_of(Patron::Session).to receive(:post).and_return(@empty_resp)
    expect(described_class.new(@conn).retrieve).to eq({"unassign" => [], "assign" => []})
  end

  it "uses segments which we pass to `retrieve` instead of default" do
    segments = {segments: {lang: "en"}}
    expect_any_instance_of(Patron::Session).to receive(:post)
                                                 .with("/experiments", JSON.dump(segments.merge(assigned: [])))
    described_class.new(@conn).retrieve(segments)
  end

  it "uses segements set in a config block" do
    expect_any_instance_of(Patron::Session).to receive(:post)
                                                 .with("/experiments", JSON.dump(segments: {country: "nl"}, assigned: []))
    conn = XpRubyClient::Configurator.new do |config|
      config.application = "web"
      config.timeout = 30
      config.segments = {country: "nl"}
    end
    described_class.new(conn).retrieve
  end
end
